#[repr(i32)]pub enum ResultOrder {
Unspecified = 0,
ByIndex = 1,
ByCompletion = 2,
}Expand description
Result ordering for item results.
Variants
Unspecified = 0
ByIndex = 1
Order results by their index in the input array (default).
ByCompletion = 2
Order results by completion time.
Implementations
Sourceimpl ResultOrder
impl ResultOrder
Sourceimpl ResultOrder
impl ResultOrder
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.