#[repr(i32)]pub enum StatusEventType {
Unspecified = 0,
RunCreated = 1,
StepStarted = 2,
StepCompleted = 3,
StepReady = 4,
ItemCompleted = 5,
RunCompleted = 6,
SubRunCreated = 7,
StepsNeeded = 8,
}Expand description
Event type for filtering GetRunEventsRequest.
Variants
Unspecified = 0
RunCreated = 1
StepStarted = 2
StepCompleted = 3
StepReady = 4
ItemCompleted = 5
RunCompleted = 6
SubRunCreated = 7
StepsNeeded = 8
Implementations
Sourceimpl StatusEventType
impl StatusEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.