pub struct ListRunsRequest {
pub status: Option<i32>,
pub flow_name: Option<String>,
pub root_run_id: Option<String>,
pub parent_run_id: Option<String>,
pub roots_only: bool,
pub max_depth: Option<u32>,
pub limit: Option<u32>,
pub offset: Option<u32>,
}Fields
status: Option<i32>Filter by execution status.
flow_name: Option<String>Filter by flow name (not flow_id).
root_run_id: Option<String>Filter to runs under this root run (UUID). Includes the root itself.
parent_run_id: Option<String>Filter to direct children of this parent run (UUID).
roots_only: boolFilter to only root runs (runs where parent_run_id is None).
max_depth: Option<u32>Maximum depth for hierarchy queries (0 = root only).
limit: Option<u32>Maximum number of results.
offset: Option<u32>Number of results to skip.
Implementations
Sourceimpl ListRunsRequest
impl ListRunsRequest
Sourcepub fn status(&self) -> ExecutionStatus
pub fn status(&self) -> ExecutionStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ExecutionStatus)
pub fn set_status(&mut self, value: ExecutionStatus)
Sets status to the provided enum value.
Sourcepub fn flow_name(&self) -> &str
pub fn flow_name(&self) -> &str
Returns the value of flow_name, or the default value if flow_name is unset.
Sourcepub fn root_run_id(&self) -> &str
pub fn root_run_id(&self) -> &str
Returns the value of root_run_id, or the default value if root_run_id is unset.
Sourcepub fn parent_run_id(&self) -> &str
pub fn parent_run_id(&self) -> &str
Returns the value of parent_run_id, or the default value if parent_run_id is unset.