pub struct OrchestratorRunStatus {
pub run_id: String,
pub flow_id: String,
pub flow_name: Option<String>,
pub status: i32,
pub items: Option<ItemStatistics>,
pub created_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
pub results: Vec<ItemResult>,
pub root_run_id: String,
pub parent_run_id: Option<String>,
pub created_at_seqno: u64,
}Fields
run_id: StringRun ID (UUID).
flow_id: Stringflow_name: Option<String>status: i32items: Option<ItemStatistics>created_at: Option<Timestamp>completed_at: Option<Timestamp>results: Vec<ItemResult>root_run_id: StringRun hierarchy fields. Root run ID (UUID). For top-level runs, equals run_id.
parent_run_id: Option<String>Parent run ID (UUID). Present only for sub-flow runs.
created_at_seqno: u64Journal sequence number of the run creation event.
Implementations
Sourceimpl OrchestratorRunStatus
impl OrchestratorRunStatus
Sourcepub fn flow_name(&self) -> &str
pub fn flow_name(&self) -> &str
Returns the value of flow_name, or the default value if flow_name is unset.
Sourcepub fn status(&self) -> ExecutionStatus
pub fn status(&self) -> ExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ExecutionStatus)
pub fn set_status(&mut self, value: ExecutionStatus)
Sets status to the provided enum value.
Sourcepub fn parent_run_id(&self) -> &str
pub fn parent_run_id(&self) -> &str
Returns the value of parent_run_id, or the default value if parent_run_id is unset.