pub struct StepCompletedEvent {
pub run_id: String,
pub item_index: u32,
pub step_index: u32,
pub step_id: Option<String>,
pub status: i32,
pub result: Option<Value>,
}Fields
run_id: StringRun ID (UUID).
item_index: u32step_index: u32step_id: Option<String>status: i32Whether the step succeeded or failed.
result: Option<Value>The step result. Only included when include_results=true.
Implementations
Sourceimpl StepCompletedEvent
impl StepCompletedEvent
Sourcepub fn step_id(&self) -> &str
pub fn step_id(&self) -> &str
Returns the value of step_id, or the default value if step_id is unset.
Sourcepub fn status(&self) -> ExecutionStatus
pub fn status(&self) -> ExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ExecutionStatus)
pub fn set_status(&mut self, value: ExecutionStatus)
Sets status to the provided enum value.