pub struct StepStatus {
pub step_id: String,
pub step_index: u32,
pub item_index: u32,
pub status: i32,
pub component: Option<String>,
pub output: Option<Value>,
pub error_message: Option<String>,
pub error_code: Option<i32>,
pub started_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
pub journal_seqno: u64,
pub updated_at: Option<Timestamp>,
}Fields
step_id: Stringstep_index: u32item_index: u32Item index (0-based). Required for batch runs.
status: i32component: Option<String>output: Option<Value>Step result (present when completed or failed).
error_message: Option<String>error_code: Option<i32>started_at: Option<Timestamp>completed_at: Option<Timestamp>journal_seqno: u64Journal sequence number of the event that produced this status.
updated_at: Option<Timestamp>When this status was last updated.
Implementations
Sourceimpl StepStatus
impl StepStatus
Sourcepub fn status(&self) -> ExecutionStatus
pub fn status(&self) -> ExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ExecutionStatus)
pub fn set_status(&mut self, value: ExecutionStatus)
Sets status to the provided enum value.
Sourcepub fn component(&self) -> &str
pub fn component(&self) -> &str
Returns the value of component, or the default value if component is unset.
Sourcepub fn error_message(&self) -> &str
pub fn error_message(&self) -> &str
Returns the value of error_message, or the default value if error_message is unset.
Sourcepub fn error_code(&self) -> TaskErrorCode
pub fn error_code(&self) -> TaskErrorCode
Returns the enum value of error_code, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_error_code(&mut self, value: TaskErrorCode)
pub fn set_error_code(&mut self, value: TaskErrorCode)
Sets error_code to the provided enum value.