pub struct TaskError {
pub code: i32,
pub message: String,
pub data: Option<Struct>,
}Expand description
Structured error type for task failures. TaskErrorCode is defined in common.proto.
Fields
code: i32Error code categorizing the failure.
message: StringHuman-readable error message.
data: Option<Struct>Optional structured error data (stack traces, error context, etc.).
Implementations
Sourceimpl TaskError
impl TaskError
Sourcepub fn code(&self) -> TaskErrorCode
pub fn code(&self) -> TaskErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: TaskErrorCode)
pub fn set_code(&mut self, value: TaskErrorCode)
Sets code to the provided enum value.