pub struct TaskHeartbeatResponse {
pub should_abort: bool,
pub status: i32,
}Fields
should_abort: boolIf true, the worker should abort execution of this task.
Check status for the reason.
status: i32Current task status from the orchestrator’s perspective.
Implementations
Sourceimpl TaskHeartbeatResponse
impl TaskHeartbeatResponse
Sourcepub fn status(&self) -> TaskStatus
pub fn status(&self) -> TaskStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TaskStatus)
pub fn set_status(&mut self, value: TaskStatus)
Sets status to the provided enum value.