pub enum Task {
Execute(Box<ComponentExecuteRequest>),
ListComponents(ListComponentsRequest),
}Expand description
The task to perform — either a component execution or a discovery request.
Variants
Execute(Box<ComponentExecuteRequest>)
Execute a component.
ListComponents(ListComponentsRequest)
List available components. Workers respond via CompleteTask with a ListComponentsResult containing their available components.
Implementations
Sourceimpl Task
impl Task
Sourcepub fn merge(
field: &mut Option<Task>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Task>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.